@@ -22,6 +22,7 @@ from .api.config import router as config_router
 from .api.browser import router as browser_router
 from .api.voices import router as voices_router
 from .api.agent import router as agent_router
+from .api.composio import router as composio_router
 
 # Import shared state
 from . import shared_state
@@ -29,6 +30,8 @@ from . import shared_state
 # Configure logging
 
 from vibe_surf.logger import get_logger
+from vibe_surf.telemetry.service import ProductTelemetry
+from vibe_surf.telemetry.views import BackendTelemetryEvent
 
 logger = get_logger(__name__)
 
@@ -55,6 +58,7 @@ app.include_router(config_router, prefix="/api", tags=["config"])
 app.include_router(browser_router, prefix="/api", tags=["browser"])
 app.include_router(voices_router, prefix="/api", tags=["voices"])
 app.include_router(agent_router, prefix="/api", tags=["agent"])
+app.include_router(composio_router, prefix="/api", tags=["composio"])
 
 # Global variable to control browser monitoring task
 browser_monitor_task = None
@@ -110,6 +114,15 @@ async def startup_event():
     """Initialize database and VibeSurf components on startup"""
     global browser_monitor_task
     
+    # Initialize telemetry and capture startup event
+    telemetry = ProductTelemetry()
+    import vibe_surf
+    startup_event = BackendTelemetryEvent(
+        version=vibe_surf.__version__,
+        action='startup'
+    )
+    telemetry.capture(startup_event)
+    
     # Initialize VibeSurf components and update shared state
     await shared_state.initialize_vibesurf_components()
 
@@ -118,6 +131,9 @@ async def startup_event():
     logger.info("🔍 Started browser connection monitor")
 
     logger.info("🚀 VibeSurf Backend API started with single-task execution model")
+    
+    # Flush telemetry
+    telemetry.flush()
 
 @app.on_event("shutdown")
 async def shutdown_event():
@@ -126,6 +142,15 @@ async def shutdown_event():
     
     logger.info("🛑 Starting graceful shutdown...")
     
+    # Capture telemetry shutdown event
+    telemetry = ProductTelemetry()
+    import vibe_surf
+    shutdown_event = BackendTelemetryEvent(
+        version=vibe_surf.__version__,
+        action='shutdown'
+    )
+    telemetry.capture(shutdown_event)
+    
     # Cancel browser monitor task
     if browser_monitor_task and not browser_monitor_task.done():
         browser_monitor_task.cancel()
@@ -153,6 +178,9 @@ async def shutdown_event():
             logger.error(f"❌ Error closing database manager: {e}")
     
     logger.info("🛑 VibeSurf Backend API stopped")
+    
+    # Flush telemetry before shutdown
+    telemetry.flush()
 
 # Health check endpoint
 @app.get("/health")
